@@ -1,5 +1,5 @@
 /*
-	SPDX-FileCopyrightText: 2010-2016 Graeme Gott <graeme@gottcode.org>
+	SPDX-FileCopyrightText: 2010-2022 Graeme Gott <graeme@gottcode.org>
 
 	SPDX-License-Identifier: GPL-3.0-or-later
 */
@@ -7,14 +7,12 @@
 #ifndef TETZLE_PATH_H
 #define TETZLE_PATH_H
 
-#include <QtGlobal>
-class QString;
+#include <QString>
 
 class Path
 {
 public:
-	static QString datapath();
-	static QString oldDataPath();
+	static void load(const QString& userdir);
 
 	static QString image(const QString& file);
 	static QString thumbnail(const QString& image, qreal pixelratio);
@@ -24,6 +22,12 @@ public:
 	static QString images();
 	static QString thumbnails();
 	static QString saves();
+
+private:
+	static QString oldDataPath();
+
+private:
+	static QString m_path;
 };
 
 #endif // TETZLE_PATH_H
