@@ -1,24 +1,11 @@
-/***********************************************************************
- *
- * Copyright (C) 2008, 2010, 2011, 2016 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2008-2016 Graeme Gott <graeme@gottcode.org>
 
-#ifndef PIECE_H
-#define PIECE_H
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
+
+#ifndef TETZLE_PIECE_H
+#define TETZLE_PIECE_H
 
 #include "graphics_layer.h"
 class Board;
@@ -135,4 +122,4 @@ inline void Piece::drawShadow() const
 	graphics_layer->draw(m_shadow_array);
 }
 
-#endif
+#endif // TETZLE_PIECE_H
